==> cost-interface-0.3.10-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/CountryPlaneAdPayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.CountryPlaneAdRegistVo;

import java.io.Serializable;
import java.util.Date;

/**
 * 全国面上广告核报
 * CountryPlaneAdPay
 * 数据库表：country_plane_ad_pay
 */
public class CountryPlaneAdPayVo implements Serializable {

    private static final long serialVersionUID = -4251422258450578790L;

    /**对应登记单行项目信息*/
    private CountryPlaneAdRegistVo countryPlaneAdRegistVo;
    /**
     *
     * 表字段 : country_plane_ad_pay.id
     */
    private Integer id;

    /**
     * 行项目号
     * 表字段 : country_plane_ad_pay.unit
     */
    private Integer itemNo;

    /**
     * 核报单号
     * 表字段 : country_plane_ad_pay.regist_no
     */
    private String registNo;

    /**
     * 登记单号
     * 表字段 : country_plane_ad_pay.pay_no
     */
    private String payNo;

    /**
     * 申请单号
     * 表字段 : country_plane_ad_pay.apply_no
     */
    private String applyNo;

    /**
     * 登记单行项目号
     * 表字段 : country_plane_ad_pay.regist_item_no
     */
    private Integer registItemNo;

    /**
     * 费用类型编码
     * 表字段 : country_plane_ad_pay.cost_type_id
     */
    private String costTypeId;

    /**
     * 费用类型名称
     * 表字段 : country_plane_ad_pay.cost_type_name
     */
    private String costTypeName;

    /**
     * 媒体大类
     * 表字段 : country_plane_ad_pay.media_big_code
     */
    private String mediaBigCode;

    /**
     * 媒体大类名称
     * 表字段 : country_plane_ad_pay.media_big_name
     */
    private String mediaBigName;

    /**
     * 媒体小类
     * 表字段 : country_plane_ad_pay.media_small_code
     */
    private String mediaSmallCode;

    /**
     * 媒体小类名称
     * 表字段 : country_plane_ad_pay.media_small_name
     */
    private String mediaSmallName;

    /**
     * 媒体内容
     * 表字段 : country_plane_ad_pay.media_content
     */
    private String mediaContent;

    /**
     * 数量
     * 表字段 : country_plane_ad_pay.count
     */
    private Integer count;

    /**
     * 活动形式
     * 表字段 : country_plane_ad_pay.activity_forms
     */
    private String activityForms;

    /**
     * 核报金额(分)
     * 表字段 : country_plane_ad_pay.pay_amount
     */
    private Long payAmount;

    /**
     * 行项目余额
     * 表字段 : country_plane_ad_pay.item_balance
     */
    private Long itemBalance;

    /**
     * 督查意见
     * 表字段 : country_plane_ad_pay.audit_notes
     */
    private String auditNotes;

    /**
     *
     * 表字段 : country_plane_ad_pay.create_id
     */
    private String createId;

    /**
     *
     * 表字段 : country_plane_ad_pay.create_name
     */
    private String createName;

    /**
     *
     * 表字段 : country_plane_ad_pay.create_date
     */
    private Date createDate;

    /**
     *
     * 表字段 : country_plane_ad_pay.modify_id
     */
    private String modifyId;

    /**
     *
     * 表字段 : country_plane_ad_pay.modify_name
     */
    private String modifyName;

    /**
     *
     * 表字段 : country_plane_ad_pay.modify_date
     */
    private Date modifyDate;

    public CountryPlaneAdRegistVo getCountryPlaneAdRegistVo() {
        return countryPlaneAdRegistVo;
    }

    public void setCountryPlaneAdRegistVo(CountryPlaneAdRegistVo countryPlaneAdRegistVo) {
        this.countryPlaneAdRegistVo = countryPlaneAdRegistVo;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getItemNo() {
        return itemNo;
    }

    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    public String getRegistNo() {
        return registNo;
    }

    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    public String getPayNo() {
        return payNo;
    }

    public void setPayNo(String payNo) {
        this.payNo = payNo;
    }

    public String getApplyNo() {
        return applyNo;
    }

    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    public Integer getRegistItemNo() {
        return registItemNo;
    }

    public void setRegistItemNo(Integer registItemNo) {
        this.registItemNo = registItemNo;
    }

    public String getCostTypeId() {
        return costTypeId;
    }

    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    public String getCostTypeName() {
        return costTypeName;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    public String getMediaBigCode() {
        return mediaBigCode;
    }

    public void setMediaBigCode(String mediaBigCode) {
        this.mediaBigCode = mediaBigCode;
    }

    public String getMediaBigName() {
        return mediaBigName;
    }

    public void setMediaBigName(String mediaBigName) {
        this.mediaBigName = mediaBigName;
    }

    public String getMediaSmallCode() {
        return mediaSmallCode;
    }

    public void setMediaSmallCode(String mediaSmallCode) {
        this.mediaSmallCode = mediaSmallCode;
    }

    public String getMediaSmallName() {
        return mediaSmallName;
    }

    public void setMediaSmallName(String mediaSmallName) {
        this.mediaSmallName = mediaSmallName;
    }

    public String getMediaContent() {
        return mediaContent;
    }

    public void setMediaContent(String mediaContent) {
        this.mediaContent = mediaContent;
    }

    public Integer getCount() {
        return count;
    }

    public void setCount(Integer count) {
        this.count = count;
    }

    public String getActivityForms() {
        return activityForms;
    }

    public void setActivityForms(String activityForms) {
        this.activityForms = activityForms;
    }

    public Long getPayAmount() {
        return payAmount;
    }

    public void setPayAmount(Long payAmount) {
        this.payAmount = payAmount;
    }

    public Long getItemBalance() {
        return itemBalance;
    }

    public void setItemBalance(Long itemBalance) {
        this.itemBalance = itemBalance;
    }

    public String getAuditNotes() {
        return auditNotes;
    }

    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    public String getCreateId() {
        return createId;
    }

    public void setCreateId(String createId) {
        this.createId = createId;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getModifyId() {
        return modifyId;
    }

    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    public String getModifyName() {
        return modifyName;
    }

    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    public Date getModifyDate() {
        return modifyDate;
    }

    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }
}

==> cost-interface-0.3.23-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/CountryPlaneAdPayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.CountryPlaneAdRegistVo;

import java.io.Serializable;
import java.util.Date;

/**
 * 全国面上广告核报
 * CountryPlaneAdPay
 * 数据库表：country_plane_ad_pay
 */
public class CountryPlaneAdPayVo implements Serializable {

    private static final long serialVersionUID = -4251422258450578790L;

    /**对应登记单行项目信息*/
    private CountryPlaneAdRegistVo registVo;
    /**
     *
     * 表字段 : country_plane_ad_pay.id
     */
    private Integer id;

    /**
     * 行项目号
     * 表字段 : country_plane_ad_pay.unit
     */
    private Integer itemNo;

    /**
     * 核报单号
     * 表字段 : country_plane_ad_pay.regist_no
     */
    private String registNo;

    /**
     * 登记单号
     * 表字段 : country_plane_ad_pay.pay_no
     */
    private String payNo;

    /**
     * 申请单号
     * 表字段 : country_plane_ad_pay.apply_no
     */
    private String applyNo;

    /**
     * 登记单行项目号
     * 表字段 : country_plane_ad_pay.regist_item_no
     */
    private Integer registItemNo;

    /**
     * 费用类型编码
     * 表字段 : country_plane_ad_pay.cost_type_id
     */
    private String costTypeId;

    /**
     * 费用类型名称
     * 表字段 : country_plane_ad_pay.cost_type_name
     */
    private String costTypeName;

    /**
     * 媒体大类
     * 表字段 : country_plane_ad_pay.media_big_code
     */
    private String mediaBigCode;

    /**
     * 媒体大类名称
     * 表字段 : country_plane_ad_pay.media_big_name
     */
    private String mediaBigName;

    /**
     * 媒体小类
     * 表字段 : country_plane_ad_pay.media_small_code
     */
    private String mediaSmallCode;

    /**
     * 媒体小类名称
     * 表字段 : country_plane_ad_pay.media_small_name
     */
    private String mediaSmallName;

    /**
     * 媒体内容
     * 表字段 : country_plane_ad_pay.media_content
     */
    private String mediaContent;

    /**
     * 数量
     * 表字段 : country_plane_ad_pay.count
     */
    private Integer count;

    /**
     * 活动形式
     * 表字段 : country_plane_ad_pay.activity_forms
     */
    private String activityForms;

    /**
     * 核报金额(分)
     * 表字段 : country_plane_ad_pay.pay_amount
     */
    private Long payAmount;

    /**
     * 行项目余额
     * 表字段 : country_plane_ad_pay.item_balance
     */
    private Long itemBalance;

    /**
     * 督查意见
     * 表字段 : country_plane_ad_pay.audit_notes
     */
    private String auditNotes;

    /**
     *
     * 表字段 : country_plane_ad_pay.create_id
     */
    private String createId;

    /**
     *
     * 表字段 : country_plane_ad_pay.create_name
     */
    private String createName;

    /**
     *
     * 表字段 : country_plane_ad_pay.create_date
     */
    private Date createDate;

    /**
     *
     * 表字段 : country_plane_ad_pay.modify_id
     */
    private String modifyId;

    /**
     *
     * 表字段 : country_plane_ad_pay.modify_name
     */
    private String modifyName;

    /**
     *
     * 表字段 : country_plane_ad_pay.modify_date
     */
    private Date modifyDate;


    public CountryPlaneAdRegistVo getRegistVo() {
		return registVo;
	}

	public void setRegistVo(CountryPlaneAdRegistVo registVo) {
		this.registVo = registVo;
	}

	public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getItemNo() {
        return itemNo;
    }

    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    public String getRegistNo() {
        return registNo;
    }

    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    public String getPayNo() {
        return payNo;
    }

    public void setPayNo(String payNo) {
        this.payNo = payNo;
    }

    public String getApplyNo() {
        return applyNo;
    }

    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    public Integer getRegistItemNo() {
        return registItemNo;
    }

    public void setRegistItemNo(Integer registItemNo) {
        this.registItemNo = registItemNo;
    }

    public String getCostTypeId() {
        return costTypeId;
    }

    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    public String getCostTypeName() {
        return costTypeName;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    public String getMediaBigCode() {
        return mediaBigCode;
    }

    public void setMediaBigCode(String mediaBigCode) {
        this.mediaBigCode = mediaBigCode;
    }

    public String getMediaBigName() {
        return mediaBigName;
    }

    public void setMediaBigName(String mediaBigName) {
        this.mediaBigName = mediaBigName;
    }

    public String getMediaSmallCode() {
        return mediaSmallCode;
    }

    public void setMediaSmallCode(String mediaSmallCode) {
        this.mediaSmallCode = mediaSmallCode;
    }

    public String getMediaSmallName() {
        return mediaSmallName;
    }

    public void setMediaSmallName(String mediaSmallName) {
        this.mediaSmallName = mediaSmallName;
    }

    public String getMediaContent() {
        return mediaContent;
    }

    public void setMediaContent(String mediaContent) {
        this.mediaContent = mediaContent;
    }

    public Integer getCount() {
        return count;
    }

    public void setCount(Integer count) {
        this.count = count;
    }

    public String getActivityForms() {
        return activityForms;
    }

    public void setActivityForms(String activityForms) {
        this.activityForms = activityForms;
    }

    public Long getPayAmount() {
        return payAmount;
    }

    public void setPayAmount(Long payAmount) {
        this.payAmount = payAmount;
    }

    public Long getItemBalance() {
        return itemBalance;
    }

    public void setItemBalance(Long itemBalance) {
        this.itemBalance = itemBalance;
    }

    public String getAuditNotes() {
        return auditNotes;
    }

    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    public String getCreateId() {
        return createId;
    }

    public void setCreateId(String createId) {
        this.createId = createId;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getModifyId() {
        return modifyId;
    }

    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    public String getModifyName() {
        return modifyName;
    }

    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    public Date getModifyDate() {
        return modifyDate;
    }

    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }
}
